@@ -67,9 +67,16 @@ public class ASTExpr extends Expr {
 		}
 	};
 
-	// used temporarily for checking obj.prop cache
-	public static int totalObjPropRefs = 0;
-	public static int totalReflectionLookups = 0;
+	/** John Snyders gave me an example implementation for this checking */
+	public static final Set supportedOptions = new HashSet() {
+		{
+			add("anchor");
+			add("format");
+			add("null");
+			add("separator");
+			add("wrap");
+		}
+	};
 
 	AST exprTree = null;
 
@@ -98,6 +105,9 @@ public class ASTExpr extends Expr {
 	 */
 	String separatorString = null;
 
+	/** A cached value of option format=expr */
+	String formatString = null;
+
 	public ASTExpr(StringTemplate enclosingTemplate, AST exprTree, Map options) {
 		super(enclosingTemplate);
         this.exprTree = exprTree;
@@ -147,7 +157,11 @@ public class ASTExpr extends Expr {
 		return n;
     }
 
-	private void handleExprOptions(StringTemplate self) {
+	/** Grab and cache options; verify options are valid */
+	protected void handleExprOptions(StringTemplate self) {
+		// make sure options don't use format / renderer.  They are usually
+		// strings which might invoke a string renderer etc...
+		formatString = null;
 		StringTemplateAST wrapAST = (StringTemplateAST)getOption("wrap");
 		if ( wrapAST!=null ) {
 			wrapString = evaluateExpression(self,wrapAST);
@@ -160,6 +174,23 @@ public class ASTExpr extends Expr {
 		if ( separatorAST!=null ) {
 			separatorString = evaluateExpression(self, separatorAST);
 		}
+		// following addition inspired by John Snyders
+		StringTemplateAST formatAST =
+			(StringTemplateAST)getOption("format");
+		if ( formatAST!=null ) {
+			formatString = evaluateExpression(self, formatAST);
+		}
+
+		// Check that option is valid
+		if ( options != null ) {
+			Iterator it = options.keySet().iterator();
+			while ( it.hasNext() ) {
+				String option = (String)it.next();
+				if (!supportedOptions.contains(option)) {
+					self.warning("ignoring unsupported option: "+option);
+				}
+			}
+		}
 	}
 
 	// HELP ROUTINES CALLED BY EVALUATOR TREE WALKER
@@ -328,6 +359,7 @@ public class ASTExpr extends Expr {
 				argumentContext.put(DEFAULT_ATTRIBUTE_NAME_DEPRECATED, attributeValue);
 			}
 			argumentContext.put(DEFAULT_INDEX_VARIABLE_NAME, new Integer(1));
+			argumentContext.put(DEFAULT_INDEX0_VARIABLE_NAME, new Integer(0));
             embedded.setArgumentContext(argumentContext);
             evaluateArguments(embedded);
             return embedded;
@@ -368,7 +400,6 @@ public class ASTExpr extends Expr {
 		if ( o==null || propertyName==null ) {
 			return null;
 		}
-		totalObjPropRefs++;
 		/*
 		// see if property is cached in group's cache
 		Object cachedValue =
@@ -465,10 +496,8 @@ public class ASTExpr extends Expr {
 		// must look up using reflection
 		String methodSuffix = Character.toUpperCase(propertyName.charAt(0))+
 			propertyName.substring(1,propertyName.length());
-		totalReflectionLookups++;
 		m = getMethod(c,"get"+methodSuffix);
 		if ( m==null ) {
-			totalReflectionLookups++;
 			m = getMethod(c, "is"+methodSuffix);
 		}
 		if ( m != null ) {
@@ -485,7 +514,6 @@ public class ASTExpr extends Expr {
 		else {
 			// try for a visible field
 			try {
-				totalReflectionLookups++;
 				Field f = c.getField(propertyName);
 				//self.getGroup().cacheClassProperty(c,propertyName,f);
 				try {
@@ -619,11 +647,16 @@ public class ASTExpr extends Expr {
      *
      *  If self is an embedded template, you might have specified
      *  a separator arg; used when is a vector.
-     */
+	 */
     public int writeAttribute(StringTemplate self, Object o, StringTemplateWriter out) {
         return write(self,o,out);
     }
 
+	/*	Write o relative to self to out.
+	 *
+	 *  John Snyders fixes here for formatString.  Basically, any time
+	 *  you are about to write a value, check formatting.
+	 */
 	protected int write(StringTemplate self,
 						Object o,
 						StringTemplateWriter out)
@@ -663,6 +696,22 @@ public class ASTExpr extends Expr {
 					if ( wrapString!=null ) {
 						n = out.writeWrapSeparator(wrapString);
 					}
+					// check if formatting needs to be applied to the stToWrite
+					if ( formatString != null ) {
+						AttributeRenderer renderer =
+							self.getAttributeRenderer(String.class);
+						if ( renderer != null ) {
+							// you pay a penalty for applying format option to a template
+							// because the template must be written to a temp StringWriter so it can
+							// be formatted before being written to the real output.
+							StringWriter buf = new StringWriter();
+							StringTemplateWriter sw =
+								self.getGroup().getStringTemplateWriter(buf);
+							stToWrite.write(sw);
+							n = out.write(renderer.toString(buf.toString(), formatString));
+							return n;
+						}
+					}
                     n = stToWrite.write(out);
                 }
                 return n;
@@ -671,7 +720,6 @@ public class ASTExpr extends Expr {
 			o = convertAnythingIteratableToIterator(o);
 			if ( o instanceof Iterator ) {
 				Iterator iter = (Iterator)o;
-				Object prevIterValue = null;
 				boolean seenPrevValue = false;
 				while ( iter.hasNext() ) {
                     Object iterValue = iter.next();
@@ -687,7 +735,6 @@ public class ASTExpr extends Expr {
 						int nw = write(self, iterValue, out);
 						n += nw;
 					}
-					prevIterValue = iterValue;
 				}
 			}
 			else {
@@ -695,7 +742,12 @@ public class ASTExpr extends Expr {
 					self.getAttributeRenderer(o.getClass());
 				String v = null;
 				if ( renderer!=null ) {
-					v = renderer.toString(o);
+					if ( formatString != null ) {
+						v = renderer.toString(o, formatString);
+					}
+					else {
+						v = renderer.toString(o);
+					}
 				}
 				else {
 					v = o.toString();
@@ -736,9 +788,8 @@ public class ASTExpr extends Expr {
 			 {
 				ActionEvaluator eval =
 						new ActionEvaluator(self,this,sw);
-				int n = 0;
 				try {
-					n = eval.action(exprAST); // eval tree
+					eval.action(exprAST); // eval tree
 				}
 				catch (RecognitionException re) {
 					self.error("can't evaluate tree: "+exprTree.toStringList(), re);
@@ -806,70 +857,19 @@ public class ASTExpr extends Expr {
 	};
 	*/
 
-	/** Do a standard conversion of array attributes to Lists.  Create
-	 *  StringTemplate.STAttributeList objects so we know they are ST
-	 *  controlled not user lists.
+	/** Do a standard conversion of array attributes to a List.  Wrap the
+	 *  array instead of copying like old version.  Make an
+	 *  ArrayWrappedInList that knows to create an ArrayIterator.
 	 */
 	public static Object convertArrayToList(Object value) {
 		if ( value==null ) {
 			return null;
 		}
-		/*
-		if ( !(value instanceof StringTemplate) ) {
-			System.out.println("convert "+value+" to array?");
-		}
-		*/
-		/*
-		if ( !arraysConvertibleToList.contains(value.getClass()) &&
-			 !(value instanceof Object[]) )
-		{
-			return value;
-		}
-		*/
-		if ( value instanceof Object[] ) {
-			Object[] list = (Object[])value;
-			List v = new StringTemplate.STAttributeList(list.length);
-			for (int i = 0; i < list.length; i++) {
-				Object elem = list[i];
-				v.add(elem);
+		if ( value.getClass().isArray() ) {
+			if ( value.getClass().getComponentType().isPrimitive() ) {
+				return new ArrayWrappedInList(value);
 			}
-			value = v;
-		}
-		else if ( value instanceof int[] ) {
-			int[] list = (int[])value;
-			List v = new StringTemplate.STAttributeList(list.length);
-			for (int i = 0; i < list.length; i++) {
-				int elem = list[i];
-				v.add(new Integer(elem));
-			}
-			value = v;
-		}
-		else if ( value instanceof long[] ) {
-			long[] list = (long[])value;
-			List v = new StringTemplate.STAttributeList(list.length);
-			for (int i = 0; i < list.length; i++) {
-				long elem = list[i];
-				v.add(new Long(elem));
-			}
-			value = v;
-		}
-		else if ( value instanceof float[] ) {
-			float[] list = (float[])value;
-			List v = new StringTemplate.STAttributeList(list.length);
-			for (int i = 0; i < list.length; i++) {
-				float elem = list[i];
-				v.add(new Float(elem));
-			}
-			value = v;
-		}
-		else if ( value instanceof double[] ) {
-			double[] list = (double[])value;
-			List v = new StringTemplate.STAttributeList(list.length);
-			for (int i = 0; i < list.length; i++) {
-				double elem = list[i];
-				v.add(new Double(elem));
-			}
-			value = v;
+			return Arrays.asList((Object[])value);
 		}
 		return value;
 	}
@@ -1006,24 +1006,31 @@ public class ASTExpr extends Expr {
 		int i = 1;		// we have at least one of something. Iterator and arrays might be empty.
 		if (attribute instanceof Map) {
 			i = ((Map)attribute).size();
-		} else if (attribute instanceof List) {
-			i = ((List)attribute).size();
-		} else if ( attribute instanceof Object[] ) {
+		}
+		else if (attribute instanceof Collection) {
+			i = ((Collection)attribute).size();
+		}
+		else if ( attribute instanceof Object[] ) {
 			Object[] list = (Object[])attribute;
 			i = list.length;
-		} else if ( attribute instanceof int[] ) {
+		}
+		else if ( attribute instanceof int[] ) {
 			int[] list = (int[])attribute;
 			i = list.length;
-		} else if ( attribute instanceof long[] ) {
+		}
+		else if ( attribute instanceof long[] ) {
 			long[] list = (long[])attribute;
 			i = list.length;
-		} else if ( attribute instanceof float[] ) {
+		}
+		else if ( attribute instanceof float[] ) {
 			float[] list = (float[])attribute;
 			i = list.length;
-		} else if ( attribute instanceof double[] ) {
+		}
+		else if ( attribute instanceof double[] ) {
 			double[] list = (double[])attribute;
 			i = list.length;
-		} else if ( attribute instanceof Iterator) {
+		}
+		else if ( attribute instanceof Iterator) {
 			Iterator it = (Iterator)attribute;
 			i = 0;
 			while ( it.hasNext() ) {
