@@ -1,4 +1,4 @@
-// $ANTLR 2.7.7 (20060906): "eval.g" -> "ActionEvaluator.java"$
+// $ANTLR 2.7.7 (2006-01-29): "eval.g" -> "ActionEvaluator.java"$
 
 /*
  [The "BSD licence"]
@@ -593,7 +593,20 @@ public ActionEvaluator() {
 			_loop8:
 			do {
 				if (_t==null) _t=ASTNULL;
-				if ((_tokenSet_0.member(_t.getType()))) {
+				switch ( _t.getType()) {
+				case APPLY:
+				case MULTI_APPLY:
+				case INCLUDE:
+				case VALUE:
+				case FUNCTION:
+				case LIST:
+				case ID:
+				case PLUS:
+				case DOT:
+				case ANONYMOUS_TEMPLATE:
+				case STRING:
+				case INT:
+				{
 					e=expr(_t);
 					_t = _retTree;
 					
@@ -602,11 +615,24 @@ public ActionEvaluator() {
 								  		elements.add(e);
 								  	}
 								  	
+					break;
 				}
-				else {
+				case NOTHING:
+				{
+					org.antlr.stringtemplate.language.StringTemplateAST tmp18_AST_in = (org.antlr.stringtemplate.language.StringTemplateAST)_t;
+					match(_t,NOTHING);
+					_t = _t.getNextSibling();
+					
+					List nullSingleton = new ArrayList() {{add(null);}};
+					elements.add(nullSingleton.iterator()); // add a blank
+					
+					break;
+				}
+				default:
+				{
 					if ( _cnt8>=1 ) { break _loop8; } else {throw new NoViableAltException(_t);}
 				}
-				
+				}
 				_cnt8++;
 			} while (true);
 			}
@@ -637,7 +663,7 @@ public ActionEvaluator() {
 		
 		try {      // for error handling
 			AST __t26 = _t;
-			org.antlr.stringtemplate.language.StringTemplateAST tmp18_AST_in = (org.antlr.stringtemplate.language.StringTemplateAST)_t;
+			org.antlr.stringtemplate.language.StringTemplateAST tmp19_AST_in = (org.antlr.stringtemplate.language.StringTemplateAST)_t;
 			match(_t,TEMPLATE);
 			_t = _t.getFirstChild();
 			{
@@ -679,7 +705,7 @@ public ActionEvaluator() {
 			case VALUE:
 			{
 				AST __t28 = _t;
-				org.antlr.stringtemplate.language.StringTemplateAST tmp19_AST_in = (org.antlr.stringtemplate.language.StringTemplateAST)_t;
+				org.antlr.stringtemplate.language.StringTemplateAST tmp20_AST_in = (org.antlr.stringtemplate.language.StringTemplateAST)_t;
 				match(_t,VALUE);
 				_t = _t.getFirstChild();
 				n=expr(_t);
@@ -726,7 +752,7 @@ public ActionEvaluator() {
 		
 		try {      // for error handling
 			AST __t24 = _t;
-			org.antlr.stringtemplate.language.StringTemplateAST tmp20_AST_in = (org.antlr.stringtemplate.language.StringTemplateAST)_t;
+			org.antlr.stringtemplate.language.StringTemplateAST tmp21_AST_in = (org.antlr.stringtemplate.language.StringTemplateAST)_t;
 			match(_t,SINGLEVALUEARG);
 			_t = _t.getFirstChild();
 			value=expr(_t);
@@ -774,7 +800,7 @@ public ActionEvaluator() {
 			case NOT:
 			{
 				AST __t30 = _t;
-				org.antlr.stringtemplate.language.StringTemplateAST tmp21_AST_in = (org.antlr.stringtemplate.language.StringTemplateAST)_t;
+				org.antlr.stringtemplate.language.StringTemplateAST tmp22_AST_in = (org.antlr.stringtemplate.language.StringTemplateAST)_t;
 				match(_t,NOT);
 				_t = _t.getFirstChild();
 				a=ifAtom(_t);
@@ -839,7 +865,7 @@ public ActionEvaluator() {
 			case ARGS:
 			{
 				AST __t37 = _t;
-				org.antlr.stringtemplate.language.StringTemplateAST tmp22_AST_in = (org.antlr.stringtemplate.language.StringTemplateAST)_t;
+				org.antlr.stringtemplate.language.StringTemplateAST tmp23_AST_in = (org.antlr.stringtemplate.language.StringTemplateAST)_t;
 				match(_t,ARGS);
 				_t = _t.getFirstChild();
 				{
@@ -896,7 +922,7 @@ public ActionEvaluator() {
 			case ASSIGN:
 			{
 				AST __t43 = _t;
-				org.antlr.stringtemplate.language.StringTemplateAST tmp23_AST_in = (org.antlr.stringtemplate.language.StringTemplateAST)_t;
+				org.antlr.stringtemplate.language.StringTemplateAST tmp24_AST_in = (org.antlr.stringtemplate.language.StringTemplateAST)_t;
 				match(_t,ASSIGN);
 				_t = _t.getFirstChild();
 				arg = (org.antlr.stringtemplate.language.StringTemplateAST)_t;
@@ -915,7 +941,7 @@ public ActionEvaluator() {
 			}
 			case DOTDOTDOT:
 			{
-				org.antlr.stringtemplate.language.StringTemplateAST tmp24_AST_in = (org.antlr.stringtemplate.language.StringTemplateAST)_t;
+				org.antlr.stringtemplate.language.StringTemplateAST tmp25_AST_in = (org.antlr.stringtemplate.language.StringTemplateAST)_t;
 				match(_t,DOTDOTDOT);
 				_t = _t.getNextSibling();
 				embedded.setPassThroughAttributes(true);
@@ -945,7 +971,7 @@ public ActionEvaluator() {
 		
 		try {      // for error handling
 			AST __t41 = _t;
-			org.antlr.stringtemplate.language.StringTemplateAST tmp25_AST_in = (org.antlr.stringtemplate.language.StringTemplateAST)_t;
+			org.antlr.stringtemplate.language.StringTemplateAST tmp26_AST_in = (org.antlr.stringtemplate.language.StringTemplateAST)_t;
 			match(_t,SINGLEVALUEARG);
 			_t = _t.getFirstChild();
 			e=expr(_t);
@@ -1005,9 +1031,11 @@ public ActionEvaluator() {
 		"FUNCTION",
 		"SINGLEVALUEARG",
 		"LIST",
+		"NOTHING",
 		"SEMI",
 		"LPAREN",
 		"RPAREN",
+		"\"elseif\"",
 		"COMMA",
 		"ID",
 		"ASSIGN",
@@ -1036,7 +1064,7 @@ public ActionEvaluator() {
 	};
 	
 	private static final long[] mk_tokenSet_0() {
-		long[] data = { 15045241520L, 0L};
+		long[] data = { 60180933296L, 0L};
 		return data;
 	}
 	public static final BitSet _tokenSet_0 = new BitSet(mk_tokenSet_0());
