@@ -1,4 +1,4 @@
-// $ANTLR 2.7.7 (20060906): "action.g" -> "ActionLexer.java"$
+// $ANTLR 2.7.7 (2006-01-29): "action.g" -> "ActionLexer.java"$
 
 /*
  [The "BSD licence"]
@@ -71,14 +71,15 @@ public ActionLexer(LexerSharedInputState state) {
 	caseSensitiveLiterals = true;
 	setCaseSensitive(true);
 	literals = new Hashtable();
-	literals.put(new ANTLRHashString("super", this), new Integer(30));
+	literals.put(new ANTLRHashString("super", this), new Integer(32));
 	literals.put(new ANTLRHashString("if", this), new Integer(8));
-	literals.put(new ANTLRHashString("first", this), new Integer(24));
-	literals.put(new ANTLRHashString("last", this), new Integer(26));
-	literals.put(new ANTLRHashString("rest", this), new Integer(25));
-	literals.put(new ANTLRHashString("trunc", this), new Integer(29));
-	literals.put(new ANTLRHashString("strip", this), new Integer(28));
-	literals.put(new ANTLRHashString("length", this), new Integer(27));
+	literals.put(new ANTLRHashString("first", this), new Integer(26));
+	literals.put(new ANTLRHashString("last", this), new Integer(28));
+	literals.put(new ANTLRHashString("rest", this), new Integer(27));
+	literals.put(new ANTLRHashString("trunc", this), new Integer(31));
+	literals.put(new ANTLRHashString("strip", this), new Integer(30));
+	literals.put(new ANTLRHashString("length", this), new Integer(29));
+	literals.put(new ANTLRHashString("elseif", this), new Integer(18));
 }
 
 public Token nextToken() throws TokenStreamException {
@@ -271,7 +272,7 @@ tryAgain:
 		}
 		}
 		{
-		_loop56:
+		_loop60:
 		do {
 			switch ( LA(1)) {
 			case 'a':  case 'b':  case 'c':  case 'd':
@@ -315,7 +316,7 @@ tryAgain:
 			}
 			default:
 			{
-				break _loop56;
+				break _loop60;
 			}
 			}
 		} while (true);
@@ -334,17 +335,17 @@ tryAgain:
 		int _saveIndex;
 		
 		{
-		int _cnt59=0;
-		_loop59:
+		int _cnt63=0;
+		_loop63:
 		do {
 			if (((LA(1) >= '0' && LA(1) <= '9'))) {
 				matchRange('0','9');
 			}
 			else {
-				if ( _cnt59>=1 ) { break _loop59; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
+				if ( _cnt63>=1 ) { break _loop63; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
 			}
 			
-			_cnt59++;
+			_cnt63++;
 		} while (true);
 		}
 		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
@@ -363,7 +364,7 @@ tryAgain:
 		match('"');
 		text.setLength(_saveIndex);
 		{
-		_loop62:
+		_loop66:
 		do {
 			if ((LA(1)=='\\')) {
 				mESC_CHAR(false,true);
@@ -372,7 +373,7 @@ tryAgain:
 				matchNot('"');
 			}
 			else {
-				break _loop62;
+				break _loop66;
 			}
 			
 		} while (true);
@@ -462,10 +463,10 @@ tryAgain:
 		match('{');
 		text.setLength(_saveIndex);
 		{
-		boolean synPredMatched66 = false;
+		boolean synPredMatched70 = false;
 		if (((_tokenSet_1.member(LA(1))) && (_tokenSet_2.member(LA(2))))) {
-			int _m66 = mark();
-			synPredMatched66 = true;
+			int _m70 = mark();
+			synPredMatched70 = true;
 			inputState.guessing++;
 			try {
 				{
@@ -473,12 +474,12 @@ tryAgain:
 				}
 			}
 			catch (RecognitionException pe) {
-				synPredMatched66 = false;
+				synPredMatched70 = false;
 			}
-			rewind(_m66);
+			rewind(_m70);
 inputState.guessing--;
 		}
-		if ( synPredMatched66 ) {
+		if ( synPredMatched70 ) {
 			args=mTEMPLATE_ARGS(false);
 			{
 			if ((_tokenSet_3.member(LA(1))) && ((LA(2) >= '\u0003' && LA(2) <= '\ufffe'))) {
@@ -509,7 +510,7 @@ inputState.guessing--;
 		
 		}
 		{
-		_loop69:
+		_loop73:
 		do {
 			if ((LA(1)=='\\') && (LA(2)=='{')) {
 				_saveIndex=text.length();
@@ -533,7 +534,7 @@ inputState.guessing--;
 				matchNot('}');
 			}
 			else {
-				break _loop69;
+				break _loop73;
 			}
 			
 		} while (true);
@@ -603,7 +604,7 @@ inputState.guessing--;
 			args.add(a.getText());
 		}
 		{
-		_loop75:
+		_loop79:
 		do {
 			if ((_tokenSet_5.member(LA(1))) && (_tokenSet_6.member(LA(2)))) {
 				{
@@ -669,7 +670,7 @@ inputState.guessing--;
 				}
 			}
 			else {
-				break _loop75;
+				break _loop79;
 			}
 			
 		} while (true);
@@ -752,7 +753,7 @@ inputState.guessing--;
 		
 		match('{');
 		{
-		_loop79:
+		_loop83:
 		do {
 			if ((LA(1)=='\\') && (LA(2)=='{')) {
 				_saveIndex=text.length();
@@ -776,7 +777,7 @@ inputState.guessing--;
 				matchNot('}');
 			}
 			else {
-				break _loop79;
+				break _loop83;
 			}
 			
 		} while (true);
@@ -951,8 +952,8 @@ inputState.guessing--;
 		int _saveIndex;
 		
 		{
-		int _cnt96=0;
-		_loop96:
+		int _cnt100=0;
+		_loop100:
 		do {
 			switch ( LA(1)) {
 			case ' ':
@@ -980,10 +981,10 @@ inputState.guessing--;
 			}
 			default:
 			{
-				if ( _cnt96>=1 ) { break _loop96; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
+				if ( _cnt100>=1 ) { break _loop100; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
 			}
 			}
-			_cnt96++;
+			_cnt100++;
 		} while (true);
 		}
 		if ( inputState.guessing==0 ) {
