@@ -1,4 +1,4 @@
-// $ANTLR 2.7.7 (20060906): "angle.bracket.template.g" -> "AngleBracketTemplateLexer.java"$
+// $ANTLR 2.7.7 (2006-01-29): "angle.bracket.template.g" -> "AngleBracketTemplateLexer.java"$
 
 /*
  [The "BSD licence"]
@@ -300,43 +300,44 @@ tryAgain:
 		int startCol = getColumn();
 		
 		
-		if ((LA(1)=='<') && (LA(2)=='\\') && (LA(3)=='n') && (LA(4)=='>') && (true) && (true) && (true)) {
+		if ((LA(1)=='<') && (LA(2)=='\\') && (_tokenSet_2.member(LA(3))) && (_tokenSet_3.member(LA(4))) && (true) && (true) && (true)) {
+			StringBuffer buf = new StringBuffer(); char uc = '\u0000';
 			_saveIndex=text.length();
-			match("<\\n>");
+			match('<');
 			text.setLength(_saveIndex);
-			text.setLength(_begin); text.append('\n'); _ttype = LITERAL;
-		}
-		else if ((LA(1)=='<') && (LA(2)=='\\') && (LA(3)=='r') && (LA(4)=='>') && (true) && (true) && (true)) {
+			{
+			int _cnt13=0;
+			_loop13:
+			do {
+				if ((LA(1)=='\\')) {
+					uc=mESC_CHAR(false);
+					buf.append(uc);
+				}
+				else {
+					if ( _cnt13>=1 ) { break _loop13; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
+				}
+				
+				_cnt13++;
+			} while (true);
+			}
 			_saveIndex=text.length();
-			match("<\\r>");
+			match('>');
 			text.setLength(_saveIndex);
-			text.setLength(_begin); text.append('\r'); _ttype = LITERAL;
-		}
-		else if ((LA(1)=='<') && (LA(2)=='\\') && (LA(3)=='t') && (LA(4)=='>') && (true) && (true) && (true)) {
-			_saveIndex=text.length();
-			match("<\\t>");
-			text.setLength(_saveIndex);
-			text.setLength(_begin); text.append('\t'); _ttype = LITERAL;
-		}
-		else if ((LA(1)=='<') && (LA(2)=='\\') && (LA(3)==' ') && (LA(4)=='>') && (true) && (true) && (true)) {
-			_saveIndex=text.length();
-			match("<\\ >");
-			text.setLength(_saveIndex);
-			text.setLength(_begin); text.append(' '); _ttype = LITERAL;
+			text.setLength(_begin); text.append(buf.toString()); _ttype = LITERAL;
 		}
 		else if ((LA(1)=='<') && (LA(2)=='!') && ((LA(3) >= '\u0001' && LA(3) <= '\ufffe')) && ((LA(4) >= '\u0001' && LA(4) <= '\ufffe')) && (true) && (true) && (true)) {
 			mCOMMENT(false);
 			_ttype = Token.SKIP;
 		}
-		else if ((LA(1)=='<') && (_tokenSet_2.member(LA(2))) && ((LA(3) >= '\u0001' && LA(3) <= '\ufffe')) && (true) && (true) && (true) && (true)) {
+		else if ((LA(1)=='<') && (_tokenSet_4.member(LA(2))) && ((LA(3) >= '\u0001' && LA(3) <= '\ufffe')) && (true) && (true) && (true) && (true)) {
 			{
-			if ((LA(1)=='<') && (LA(2)=='i') && (LA(3)=='f') && (LA(4)==' '||LA(4)=='(') && (_tokenSet_3.member(LA(5))) && ((LA(6) >= '\u0001' && LA(6) <= '\ufffe')) && ((LA(7) >= '\u0001' && LA(7) <= '\ufffe'))) {
+			if ((LA(1)=='<') && (LA(2)=='i') && (LA(3)=='f') && (LA(4)==' '||LA(4)=='(') && (_tokenSet_5.member(LA(5))) && ((LA(6) >= '\u0001' && LA(6) <= '\ufffe')) && ((LA(7) >= '\u0001' && LA(7) <= '\ufffe'))) {
 				_saveIndex=text.length();
 				match('<');
 				text.setLength(_saveIndex);
 				match("if");
 				{
-				_loop14:
+				_loop16:
 				do {
 					if ((LA(1)==' ')) {
 						_saveIndex=text.length();
@@ -344,7 +345,7 @@ tryAgain:
 						text.setLength(_saveIndex);
 					}
 					else {
-						break _loop14;
+						break _loop16;
 					}
 					
 				} while (true);
@@ -467,7 +468,7 @@ tryAgain:
 				
 				}
 			}
-			else if ((LA(1)=='<') && (LA(2)=='@') && (_tokenSet_4.member(LA(3))) && ((LA(4) >= '\u0001' && LA(4) <= '\ufffe')) && ((LA(5) >= '\u0001' && LA(5) <= '\ufffe')) && ((LA(6) >= '\u0001' && LA(6) <= '\ufffe')) && (true)) {
+			else if ((LA(1)=='<') && (LA(2)=='@') && (_tokenSet_6.member(LA(3))) && ((LA(4) >= '\u0001' && LA(4) <= '\ufffe')) && ((LA(5) >= '\u0001' && LA(5) <= '\ufffe')) && ((LA(6) >= '\u0001' && LA(6) <= '\ufffe')) && (true)) {
 				_saveIndex=text.length();
 				match('<');
 				text.setLength(_saveIndex);
@@ -475,19 +476,19 @@ tryAgain:
 				match('@');
 				text.setLength(_saveIndex);
 				{
-				int _cnt23=0;
-				_loop23:
+				int _cnt25=0;
+				_loop25:
 				do {
-					if ((_tokenSet_4.member(LA(1)))) {
+					if ((_tokenSet_6.member(LA(1)))) {
 						{
-						match(_tokenSet_4);
+						match(_tokenSet_6);
 						}
 					}
 					else {
-						if ( _cnt23>=1 ) { break _loop23; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
+						if ( _cnt25>=1 ) { break _loop25; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
 					}
 					
-					_cnt23++;
+					_cnt25++;
 				} while (true);
 				}
 				{
@@ -548,8 +549,8 @@ tryAgain:
 					}
 					boolean atLeft = false;
 					{
-					int _cnt30=0;
-					_loop30:
+					int _cnt32=0;
+					_loop32:
 					do {
 						if ((((LA(1) >= '\u0001' && LA(1) <= '\ufffe')) && ((LA(2) >= '\u0001' && LA(2) <= '\ufffe')) && (true) && (true) && (true) && (true) && (true))&&(!(upcomingAtEND(1)||(upcomingNewline(1)&&upcomingAtEND(2))))) {
 							{
@@ -585,10 +586,10 @@ tryAgain:
 							}
 						}
 						else {
-							if ( _cnt30>=1 ) { break _loop30; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
+							if ( _cnt32>=1 ) { break _loop32; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
 						}
 						
-						_cnt30++;
+						_cnt32++;
 					} while (true);
 					}
 					{
@@ -678,7 +679,7 @@ tryAgain:
 				}
 				}
 			}
-			else if ((LA(1)=='<') && (_tokenSet_2.member(LA(2))) && ((LA(3) >= '\u0001' && LA(3) <= '\ufffe')) && (true) && (true) && (true) && (true)) {
+			else if ((LA(1)=='<') && (_tokenSet_4.member(LA(2))) && ((LA(3) >= '\u0001' && LA(3) <= '\ufffe')) && (true) && (true) && (true) && (true)) {
 				_saveIndex=text.length();
 				match('<');
 				text.setLength(_saveIndex);
@@ -708,6 +709,74 @@ tryAgain:
 		_returnToken = _token;
 	}
 	
+	protected final char  mESC_CHAR(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
+		char uc='\u0000';
+		int _ttype; Token _token=null; int _begin=text.length();
+		_ttype = ESC_CHAR;
+		int _saveIndex;
+		Token a=null;
+		Token b=null;
+		Token c=null;
+		Token d=null;
+		
+		if ((LA(1)=='\\') && (LA(2)=='n')) {
+			_saveIndex=text.length();
+			match("\\n");
+			text.setLength(_saveIndex);
+			uc = '\n';
+		}
+		else if ((LA(1)=='\\') && (LA(2)=='r')) {
+			_saveIndex=text.length();
+			match("\\r");
+			text.setLength(_saveIndex);
+			uc = '\r';
+		}
+		else if ((LA(1)=='\\') && (LA(2)=='t')) {
+			_saveIndex=text.length();
+			match("\\t");
+			text.setLength(_saveIndex);
+			uc = '\t';
+		}
+		else if ((LA(1)=='\\') && (LA(2)==' ')) {
+			_saveIndex=text.length();
+			match("\\ ");
+			text.setLength(_saveIndex);
+			uc = ' ';
+		}
+		else if ((LA(1)=='\\') && (LA(2)=='u')) {
+			_saveIndex=text.length();
+			match("\\u");
+			text.setLength(_saveIndex);
+			_saveIndex=text.length();
+			mHEX(true);
+			text.setLength(_saveIndex);
+			a=_returnToken;
+			_saveIndex=text.length();
+			mHEX(true);
+			text.setLength(_saveIndex);
+			b=_returnToken;
+			_saveIndex=text.length();
+			mHEX(true);
+			text.setLength(_saveIndex);
+			c=_returnToken;
+			_saveIndex=text.length();
+			mHEX(true);
+			text.setLength(_saveIndex);
+			d=_returnToken;
+			uc = (char)Integer.parseInt(a.getText()+b.getText()+c.getText()+d.getText(), 16);
+		}
+		else {
+			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());
+		}
+		
+		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
+			_token = makeToken(_ttype);
+			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
+		}
+		_returnToken = _token;
+		return uc;
+	}
+	
 	protected final void mCOMMENT(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
 		int _ttype; Token _token=null; int _begin=text.length();
 		_ttype = COMMENT;
@@ -718,10 +787,10 @@ tryAgain:
 		
 		match("<!");
 		{
-		_loop66:
+		_loop70:
 		do {
 			// nongreedy exit test
-			if ((LA(1)=='!') && (LA(2)=='>') && (true) && (true) && (true) && (true) && (true)) break _loop66;
+			if ((LA(1)=='!') && (LA(2)=='>') && (true) && (true) && (true) && (true) && (true)) break _loop70;
 			if ((LA(1)=='\n'||LA(1)=='\r') && ((LA(2) >= '\u0001' && LA(2) <= '\ufffe')) && ((LA(3) >= '\u0001' && LA(3) <= '\ufffe')) && (true) && (true) && (true) && (true)) {
 				{
 				switch ( LA(1)) {
@@ -747,7 +816,7 @@ tryAgain:
 				matchNot(EOF_CHAR);
 			}
 			else {
-				break _loop66;
+				break _loop70;
 			}
 			
 		} while (true);
@@ -792,8 +861,8 @@ tryAgain:
 		int _saveIndex;
 		
 		{
-		int _cnt55=0;
-		_loop55:
+		int _cnt57=0;
+		_loop57:
 		do {
 			switch ( LA(1)) {
 			case '\\':
@@ -835,14 +904,14 @@ tryAgain:
 				break;
 			}
 			default:
-				if ((_tokenSet_5.member(LA(1)))) {
+				if ((_tokenSet_7.member(LA(1)))) {
 					matchNot(')');
 				}
 			else {
-				if ( _cnt55>=1 ) { break _loop55; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
+				if ( _cnt57>=1 ) { break _loop57; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
 			}
 			}
-			_cnt55++;
+			_cnt57++;
 		} while (true);
 		}
 		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
@@ -858,8 +927,8 @@ tryAgain:
 		int _saveIndex;
 		
 		{
-		int _cnt43=0;
-		_loop43:
+		int _cnt45=0;
+		_loop45:
 		do {
 			switch ( LA(1)) {
 			case '\\':
@@ -938,7 +1007,7 @@ tryAgain:
 					}
 					mSUBTEMPLATE(false);
 				}
-				else if ((LA(1)=='+'||LA(1)=='=') && (_tokenSet_6.member(LA(2)))) {
+				else if ((LA(1)=='+'||LA(1)=='=') && (_tokenSet_8.member(LA(2)))) {
 					{
 					switch ( LA(1)) {
 					case '=':
@@ -958,17 +1027,17 @@ tryAgain:
 					}
 					}
 					{
-					match(_tokenSet_6);
+					match(_tokenSet_8);
 					}
 				}
-				else if ((_tokenSet_7.member(LA(1)))) {
+				else if ((_tokenSet_9.member(LA(1)))) {
 					matchNot('>');
 				}
 			else {
-				if ( _cnt43>=1 ) { break _loop43; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
+				if ( _cnt45>=1 ) { break _loop45; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
 			}
 			}
-			_cnt43++;
+			_cnt45++;
 		} while (true);
 		}
 		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
@@ -999,7 +1068,7 @@ tryAgain:
 		
 		match('{');
 		{
-		_loop59:
+		_loop63:
 		do {
 			switch ( LA(1)) {
 			case '{':
@@ -1013,11 +1082,11 @@ tryAgain:
 				break;
 			}
 			default:
-				if ((_tokenSet_8.member(LA(1)))) {
+				if ((_tokenSet_10.member(LA(1)))) {
 					matchNot('}');
 				}
 			else {
-				break _loop59;
+				break _loop63;
 			}
 			}
 		} while (true);
@@ -1040,16 +1109,16 @@ tryAgain:
 		{
 			match('"');
 			{
-			_loop46:
+			_loop48:
 			do {
 				if ((LA(1)=='\\')) {
 					mESC(false);
 				}
-				else if ((_tokenSet_9.member(LA(1)))) {
+				else if ((_tokenSet_11.member(LA(1)))) {
 					matchNot('"');
 				}
 				else {
-					break _loop46;
+					break _loop48;
 				}
 				
 			} while (true);
@@ -1094,10 +1163,10 @@ tryAgain:
 			
 			}
 			{
-			_loop51:
+			_loop53:
 			do {
 				// nongreedy exit test
-				if ((LA(1)=='>') && (LA(2)=='>') && ((LA(3) >= '\u0001' && LA(3) <= '\ufffe')) && (true) && (true) && (true) && (true)) break _loop51;
+				if ((LA(1)=='>') && (LA(2)=='>') && ((LA(3) >= '\u0001' && LA(3) <= '\ufffe')) && (true) && (true) && (true) && (true)) break _loop53;
 				if (((LA(1)=='\r') && (LA(2)=='\n') && ((LA(3) >= '\u0001' && LA(3) <= '\ufffe')) && ((LA(4) >= '\u0001' && LA(4) <= '\ufffe')) && ((LA(5) >= '\u0001' && LA(5) <= '\ufffe')) && (true) && (true))&&(LA(3)=='>'&&LA(4)=='>')) {
 					_saveIndex=text.length();
 					match('\r');
@@ -1138,7 +1207,7 @@ tryAgain:
 					matchNot(EOF_CHAR);
 				}
 				else {
-					break _loop51;
+					break _loop53;
 				}
 				
 			} while (true);
@@ -1165,8 +1234,8 @@ tryAgain:
 		
 		match('(');
 		{
-		int _cnt62=0;
-		_loop62:
+		int _cnt66=0;
+		_loop66:
 		do {
 			switch ( LA(1)) {
 			case '(':
@@ -1180,14 +1249,14 @@ tryAgain:
 				break;
 			}
 			default:
-				if ((_tokenSet_10.member(LA(1)))) {
+				if ((_tokenSet_12.member(LA(1)))) {
 					matchNot(')');
 				}
 			else {
-				if ( _cnt62>=1 ) { break _loop62; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
+				if ( _cnt66>=1 ) { break _loop66; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
 			}
 			}
-			_cnt62++;
+			_cnt66++;
 		} while (true);
 		}
 		match(')');
@@ -1198,6 +1267,43 @@ tryAgain:
 		_returnToken = _token;
 	}
 	
+	protected final void mHEX(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
+		int _ttype; Token _token=null; int _begin=text.length();
+		_ttype = HEX;
+		int _saveIndex;
+		
+		switch ( LA(1)) {
+		case '0':  case '1':  case '2':  case '3':
+		case '4':  case '5':  case '6':  case '7':
+		case '8':  case '9':
+		{
+			matchRange('0','9');
+			break;
+		}
+		case 'A':  case 'B':  case 'C':  case 'D':
+		case 'E':  case 'F':
+		{
+			matchRange('A','F');
+			break;
+		}
+		case 'a':  case 'b':  case 'c':  case 'd':
+		case 'e':  case 'f':
+		{
+			matchRange('a','f');
+			break;
+		}
+		default:
+		{
+			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());
+		}
+		}
+		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
+			_token = makeToken(_ttype);
+			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
+		}
+		_returnToken = _token;
+	}
+	
 	
 	private static final long[] mk_tokenSet_0() {
 		long[] data = new long[2048];
@@ -1216,24 +1322,22 @@ tryAgain:
 	}
 	public static final BitSet _tokenSet_1 = new BitSet(mk_tokenSet_1());
 	private static final long[] mk_tokenSet_2() {
-		long[] data = new long[2048];
-		data[0]=-4611686018427387906L;
-		for (int i = 1; i<=1022; i++) { data[i]=-1L; }
-		data[1023]=9223372036854775807L;
+		long[] data = new long[1025];
+		data[0]=4294967296L;
+		data[1]=14707067533131776L;
 		return data;
 	}
 	public static final BitSet _tokenSet_2 = new BitSet(mk_tokenSet_2());
 	private static final long[] mk_tokenSet_3() {
-		long[] data = new long[2048];
-		data[0]=-2199023255554L;
-		for (int i = 1; i<=1022; i++) { data[i]=-1L; }
-		data[1023]=9223372036854775807L;
+		long[] data = new long[1025];
+		data[0]=4899634919602388992L;
+		data[1]=541434314878L;
 		return data;
 	}
 	public static final BitSet _tokenSet_3 = new BitSet(mk_tokenSet_3());
 	private static final long[] mk_tokenSet_4() {
 		long[] data = new long[2048];
-		data[0]=-4611687117939015682L;
+		data[0]=-4611686018427387906L;
 		for (int i = 1; i<=1022; i++) { data[i]=-1L; }
 		data[1023]=9223372036854775807L;
 		return data;
@@ -1241,25 +1345,23 @@ tryAgain:
 	public static final BitSet _tokenSet_4 = new BitSet(mk_tokenSet_4());
 	private static final long[] mk_tokenSet_5() {
 		long[] data = new long[2048];
-		data[0]=-3298534892546L;
-		data[1]=-576460752571858945L;
-		for (int i = 2; i<=1022; i++) { data[i]=-1L; }
+		data[0]=-2199023255554L;
+		for (int i = 1; i<=1022; i++) { data[i]=-1L; }
 		data[1023]=9223372036854775807L;
 		return data;
 	}
 	public static final BitSet _tokenSet_5 = new BitSet(mk_tokenSet_5());
 	private static final long[] mk_tokenSet_6() {
 		long[] data = new long[2048];
-		data[0]=-1152921521786716162L;
-		data[1]=-576460752303423489L;
-		for (int i = 2; i<=1022; i++) { data[i]=-1L; }
+		data[0]=-4611687117939015682L;
+		for (int i = 1; i<=1022; i++) { data[i]=-1L; }
 		data[1023]=9223372036854775807L;
 		return data;
 	}
 	public static final BitSet _tokenSet_6 = new BitSet(mk_tokenSet_6());
 	private static final long[] mk_tokenSet_7() {
 		long[] data = new long[2048];
-		data[0]=-6917537823734113282L;
+		data[0]=-3298534892546L;
 		data[1]=-576460752571858945L;
 		for (int i = 2; i<=1022; i++) { data[i]=-1L; }
 		data[1023]=9223372036854775807L;
@@ -1268,8 +1370,8 @@ tryAgain:
 	public static final BitSet _tokenSet_7 = new BitSet(mk_tokenSet_7());
 	private static final long[] mk_tokenSet_8() {
 		long[] data = new long[2048];
-		data[0]=-2L;
-		data[1]=-2882303761785552897L;
+		data[0]=-1152921521786716162L;
+		data[1]=-576460752303423489L;
 		for (int i = 2; i<=1022; i++) { data[i]=-1L; }
 		data[1023]=9223372036854775807L;
 		return data;
@@ -1277,14 +1379,32 @@ tryAgain:
 	public static final BitSet _tokenSet_8 = new BitSet(mk_tokenSet_8());
 	private static final long[] mk_tokenSet_9() {
 		long[] data = new long[2048];
-		data[0]=-17179869186L;
-		data[1]=-268435457L;
+		data[0]=-6917537823734113282L;
+		data[1]=-576460752571858945L;
 		for (int i = 2; i<=1022; i++) { data[i]=-1L; }
 		data[1023]=9223372036854775807L;
 		return data;
 	}
 	public static final BitSet _tokenSet_9 = new BitSet(mk_tokenSet_9());
 	private static final long[] mk_tokenSet_10() {
+		long[] data = new long[2048];
+		data[0]=-2L;
+		data[1]=-2882303761785552897L;
+		for (int i = 2; i<=1022; i++) { data[i]=-1L; }
+		data[1023]=9223372036854775807L;
+		return data;
+	}
+	public static final BitSet _tokenSet_10 = new BitSet(mk_tokenSet_10());
+	private static final long[] mk_tokenSet_11() {
+		long[] data = new long[2048];
+		data[0]=-17179869186L;
+		data[1]=-268435457L;
+		for (int i = 2; i<=1022; i++) { data[i]=-1L; }
+		data[1023]=9223372036854775807L;
+		return data;
+	}
+	public static final BitSet _tokenSet_11 = new BitSet(mk_tokenSet_11());
+	private static final long[] mk_tokenSet_12() {
 		long[] data = new long[2048];
 		data[0]=-3298534883330L;
 		data[1]=-268435457L;
@@ -1292,6 +1412,6 @@ tryAgain:
 		data[1023]=9223372036854775807L;
 		return data;
 	}
-	public static final BitSet _tokenSet_10 = new BitSet(mk_tokenSet_10());
+	public static final BitSet _tokenSet_12 = new BitSet(mk_tokenSet_12());
 	
 	}
