@@ -1,4 +1,4 @@
-// $ANTLR 2.7.7 (20060906): "template.g" -> "DefaultTemplateLexer.java"$
+// $ANTLR 2.7.7 (2006-01-29): "template.g" -> "DefaultTemplateLexer.java"$
 
 /*
  [The "BSD licence"]
@@ -169,8 +169,8 @@ tryAgain:
 		if (!(LA(1)!='\r'&&LA(1)!='\n'))
 		  throw new SemanticException("LA(1)!='\\r'&&LA(1)!='\\n'");
 		{
-		int _cnt9=0;
-		_loop9:
+		int _cnt11=0;
+		_loop11:
 		do {
 			
 			int loopStartIndex=text.length();
@@ -210,10 +210,10 @@ tryAgain:
 				}
 			}
 			else {
-				if ( _cnt9>=1 ) { break _loop9; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
+				if ( _cnt11>=1 ) { break _loop11; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
 			}
 			
-			_cnt9++;
+			_cnt11++;
 		} while (true);
 		}
 		if ((new String(text.getBuffer(),_begin,text.length()-_begin)).length()==0) {_ttype = Token.SKIP;}
@@ -230,8 +230,8 @@ tryAgain:
 		int _saveIndex;
 		
 		{
-		int _cnt66=0;
-		_loop66:
+		int _cnt76=0;
+		_loop76:
 		do {
 			if ((LA(1)==' ') && (true) && (true) && (true) && (true) && (true) && (true)) {
 				match(' ');
@@ -240,10 +240,10 @@ tryAgain:
 				match('\t');
 			}
 			else {
-				if ( _cnt66>=1 ) { break _loop66; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
+				if ( _cnt76>=1 ) { break _loop76; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
 			}
 			
-			_cnt66++;
+			_cnt76++;
 		} while (true);
 		}
 		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
@@ -292,29 +292,30 @@ tryAgain:
 		int startCol = getColumn();
 		
 		
-		if ((LA(1)=='$') && (LA(2)=='\\') && (LA(3)=='n') && (LA(4)=='$') && (true) && (true) && (true)) {
+		if ((LA(1)=='$') && (LA(2)=='\\') && (_tokenSet_2.member(LA(3))) && (_tokenSet_3.member(LA(4))) && (true) && (true) && (true)) {
+			StringBuffer buf = new StringBuffer(); char uc = '\u0000';
 			_saveIndex=text.length();
-			match("$\\n$");
+			match('$');
 			text.setLength(_saveIndex);
-			text.setLength(_begin); text.append('\n'); _ttype = LITERAL;
-		}
-		else if ((LA(1)=='$') && (LA(2)=='\\') && (LA(3)=='r') && (LA(4)=='$') && (true) && (true) && (true)) {
+			{
+			int _cnt16=0;
+			_loop16:
+			do {
+				if ((LA(1)=='\\')) {
+					uc=mESC_CHAR(false);
+					buf.append(uc);
+				}
+				else {
+					if ( _cnt16>=1 ) { break _loop16; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
+				}
+				
+				_cnt16++;
+			} while (true);
+			}
 			_saveIndex=text.length();
-			match("$\\r$");
+			match('$');
 			text.setLength(_saveIndex);
-			text.setLength(_begin); text.append('\r'); _ttype = LITERAL;
-		}
-		else if ((LA(1)=='$') && (LA(2)=='\\') && (LA(3)=='t') && (LA(4)=='$') && (true) && (true) && (true)) {
-			_saveIndex=text.length();
-			match("$\\t$");
-			text.setLength(_saveIndex);
-			text.setLength(_begin); text.append('\t'); _ttype = LITERAL;
-		}
-		else if ((LA(1)=='$') && (LA(2)=='\\') && (LA(3)==' ') && (LA(4)=='$') && (true) && (true) && (true)) {
-			_saveIndex=text.length();
-			match("$\\ $");
-			text.setLength(_saveIndex);
-			text.setLength(_begin); text.append(' '); _ttype = LITERAL;
+			text.setLength(_begin); text.append(buf.toString()); _ttype = LITERAL;
 		}
 		else if ((LA(1)=='$') && (LA(2)=='!') && ((LA(3) >= '\u0001' && LA(3) <= '\ufffe')) && ((LA(4) >= '\u0001' && LA(4) <= '\ufffe')) && (true) && (true) && (true)) {
 			mCOMMENT(false);
@@ -322,13 +323,13 @@ tryAgain:
 		}
 		else if ((LA(1)=='$') && (_tokenSet_1.member(LA(2))) && ((LA(3) >= '\u0001' && LA(3) <= '\ufffe')) && (true) && (true) && (true) && (true)) {
 			{
-			if ((LA(1)=='$') && (LA(2)=='i') && (LA(3)=='f') && (LA(4)==' '||LA(4)=='(') && (_tokenSet_2.member(LA(5))) && ((LA(6) >= '\u0001' && LA(6) <= '\ufffe')) && ((LA(7) >= '\u0001' && LA(7) <= '\ufffe'))) {
+			if ((LA(1)=='$') && (LA(2)=='i') && (LA(3)=='f') && (LA(4)==' '||LA(4)=='(') && (_tokenSet_4.member(LA(5))) && ((LA(6) >= '\u0001' && LA(6) <= '\ufffe')) && ((LA(7) >= '\u0001' && LA(7) <= '\ufffe'))) {
 				_saveIndex=text.length();
 				match('$');
 				text.setLength(_saveIndex);
 				match("if");
 				{
-				_loop15:
+				_loop19:
 				do {
 					if ((LA(1)==' ')) {
 						_saveIndex=text.length();
@@ -336,7 +337,7 @@ tryAgain:
 						text.setLength(_saveIndex);
 					}
 					else {
-						break _loop15;
+						break _loop19;
 					}
 					
 				} while (true);
@@ -379,6 +380,63 @@ tryAgain:
 				
 				}
 			}
+			else if ((LA(1)=='$') && (LA(2)=='e') && (LA(3)=='l') && (LA(4)=='s') && (LA(5)=='e') && (LA(6)=='i') && (LA(7)=='f')) {
+				_saveIndex=text.length();
+				match('$');
+				text.setLength(_saveIndex);
+				match("elseif");
+				{
+				_loop23:
+				do {
+					if ((LA(1)==' ')) {
+						_saveIndex=text.length();
+						match(' ');
+						text.setLength(_saveIndex);
+					}
+					else {
+						break _loop23;
+					}
+					
+				} while (true);
+				}
+				match("(");
+				mIF_EXPR(false);
+				match(")");
+				_saveIndex=text.length();
+				match('$');
+				text.setLength(_saveIndex);
+				_ttype = TemplateParser.ELSEIF;
+				{
+				if ((LA(1)=='\n'||LA(1)=='\r')) {
+					{
+					switch ( LA(1)) {
+					case '\r':
+					{
+						_saveIndex=text.length();
+						match('\r');
+						text.setLength(_saveIndex);
+						break;
+					}
+					case '\n':
+					{
+						break;
+					}
+					default:
+					{
+						throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());
+					}
+					}
+					}
+					_saveIndex=text.length();
+					match('\n');
+					text.setLength(_saveIndex);
+					newline();
+				}
+				else {
+				}
+				
+				}
+			}
 			else if ((LA(1)=='$') && (LA(2)=='e') && (LA(3)=='n') && (LA(4)=='d') && (LA(5)=='i') && (LA(6)=='f') && (LA(7)=='$')) {
 				_saveIndex=text.length();
 				match('$');
@@ -459,7 +517,7 @@ tryAgain:
 				
 				}
 			}
-			else if ((LA(1)=='$') && (LA(2)=='@') && (_tokenSet_3.member(LA(3))) && ((LA(4) >= '\u0001' && LA(4) <= '\ufffe')) && ((LA(5) >= '\u0001' && LA(5) <= '\ufffe')) && ((LA(6) >= '\u0001' && LA(6) <= '\ufffe')) && (true)) {
+			else if ((LA(1)=='$') && (LA(2)=='@') && (_tokenSet_5.member(LA(3))) && ((LA(4) >= '\u0001' && LA(4) <= '\ufffe')) && ((LA(5) >= '\u0001' && LA(5) <= '\ufffe')) && ((LA(6) >= '\u0001' && LA(6) <= '\ufffe')) && (true)) {
 				_saveIndex=text.length();
 				match('$');
 				text.setLength(_saveIndex);
@@ -467,19 +525,19 @@ tryAgain:
 				match('@');
 				text.setLength(_saveIndex);
 				{
-				int _cnt24=0;
-				_loop24:
+				int _cnt32=0;
+				_loop32:
 				do {
-					if ((_tokenSet_3.member(LA(1)))) {
+					if ((_tokenSet_5.member(LA(1)))) {
 						{
-						match(_tokenSet_3);
+						match(_tokenSet_5);
 						}
 					}
 					else {
-						if ( _cnt24>=1 ) { break _loop24; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
+						if ( _cnt32>=1 ) { break _loop32; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
 					}
 					
-					_cnt24++;
+					_cnt32++;
 				} while (true);
 				}
 				{
@@ -539,8 +597,8 @@ tryAgain:
 					}
 					boolean atLeft = false;
 					{
-					int _cnt31=0;
-					_loop31:
+					int _cnt39=0;
+					_loop39:
 					do {
 						if ((((LA(1) >= '\u0001' && LA(1) <= '\ufffe')) && ((LA(2) >= '\u0001' && LA(2) <= '\ufffe')) && (true) && (true) && (true) && (true) && (true))&&(!(upcomingAtEND(1)||(upcomingNewline(1)&&upcomingAtEND(2))))) {
 							{
@@ -576,10 +634,10 @@ tryAgain:
 							}
 						}
 						else {
-							if ( _cnt31>=1 ) { break _loop31; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
+							if ( _cnt39>=1 ) { break _loop39; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
 						}
 						
-						_cnt31++;
+						_cnt39++;
 					} while (true);
 					}
 					{
@@ -699,6 +757,74 @@ tryAgain:
 		_returnToken = _token;
 	}
 	
+	protected final char  mESC_CHAR(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
+		char uc='\u0000';
+		int _ttype; Token _token=null; int _begin=text.length();
+		_ttype = ESC_CHAR;
+		int _saveIndex;
+		Token a=null;
+		Token b=null;
+		Token c=null;
+		Token d=null;
+		
+		if ((LA(1)=='\\') && (LA(2)=='n')) {
+			_saveIndex=text.length();
+			match("\\n");
+			text.setLength(_saveIndex);
+			uc = '\n';
+		}
+		else if ((LA(1)=='\\') && (LA(2)=='r')) {
+			_saveIndex=text.length();
+			match("\\r");
+			text.setLength(_saveIndex);
+			uc = '\r';
+		}
+		else if ((LA(1)=='\\') && (LA(2)=='t')) {
+			_saveIndex=text.length();
+			match("\\t");
+			text.setLength(_saveIndex);
+			uc = '\t';
+		}
+		else if ((LA(1)=='\\') && (LA(2)==' ')) {
+			_saveIndex=text.length();
+			match("\\ ");
+			text.setLength(_saveIndex);
+			uc = ' ';
+		}
+		else if ((LA(1)=='\\') && (LA(2)=='u')) {
+			_saveIndex=text.length();
+			match("\\u");
+			text.setLength(_saveIndex);
+			_saveIndex=text.length();
+			mHEX(true);
+			text.setLength(_saveIndex);
+			a=_returnToken;
+			_saveIndex=text.length();
+			mHEX(true);
+			text.setLength(_saveIndex);
+			b=_returnToken;
+			_saveIndex=text.length();
+			mHEX(true);
+			text.setLength(_saveIndex);
+			c=_returnToken;
+			_saveIndex=text.length();
+			mHEX(true);
+			text.setLength(_saveIndex);
+			d=_returnToken;
+			uc = (char)Integer.parseInt(a.getText()+b.getText()+c.getText()+d.getText(), 16);
+		}
+		else {
+			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());
+		}
+		
+		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
+			_token = makeToken(_ttype);
+			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
+		}
+		_returnToken = _token;
+		return uc;
+	}
+	
 	protected final void mCOMMENT(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
 		int _ttype; Token _token=null; int _begin=text.length();
 		_ttype = COMMENT;
@@ -709,10 +835,10 @@ tryAgain:
 		
 		match("$!");
 		{
-		_loop70:
+		_loop80:
 		do {
 			// nongreedy exit test
-			if ((LA(1)=='!') && (LA(2)=='$') && (true) && (true) && (true) && (true) && (true)) break _loop70;
+			if ((LA(1)=='!') && (LA(2)=='$') && (true) && (true) && (true) && (true) && (true)) break _loop80;
 			if ((LA(1)=='\n'||LA(1)=='\r') && ((LA(2) >= '\u0001' && LA(2) <= '\ufffe')) && ((LA(3) >= '\u0001' && LA(3) <= '\ufffe')) && (true) && (true) && (true) && (true)) {
 				{
 				switch ( LA(1)) {
@@ -738,7 +864,7 @@ tryAgain:
 				matchNot(EOF_CHAR);
 			}
 			else {
-				break _loop70;
+				break _loop80;
 			}
 			
 		} while (true);
@@ -783,8 +909,8 @@ tryAgain:
 		int _saveIndex;
 		
 		{
-		int _cnt56=0;
-		_loop56:
+		int _cnt64=0;
+		_loop64:
 		do {
 			switch ( LA(1)) {
 			case '\\':
@@ -826,14 +952,14 @@ tryAgain:
 				break;
 			}
 			default:
-				if ((_tokenSet_4.member(LA(1)))) {
+				if ((_tokenSet_6.member(LA(1)))) {
 					matchNot(')');
 				}
 			else {
-				if ( _cnt56>=1 ) { break _loop56; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
+				if ( _cnt64>=1 ) { break _loop64; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
 			}
 			}
-			_cnt56++;
+			_cnt64++;
 		} while (true);
 		}
 		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
@@ -849,8 +975,8 @@ tryAgain:
 		int _saveIndex;
 		
 		{
-		int _cnt44=0;
-		_loop44:
+		int _cnt52=0;
+		_loop52:
 		do {
 			switch ( LA(1)) {
 			case '\\':
@@ -929,7 +1055,7 @@ tryAgain:
 					}
 					mSUBTEMPLATE(false);
 				}
-				else if ((LA(1)=='+'||LA(1)=='=') && (_tokenSet_5.member(LA(2)))) {
+				else if ((LA(1)=='+'||LA(1)=='=') && (_tokenSet_7.member(LA(2)))) {
 					{
 					switch ( LA(1)) {
 					case '=':
@@ -949,17 +1075,17 @@ tryAgain:
 					}
 					}
 					{
-					match(_tokenSet_5);
+					match(_tokenSet_7);
 					}
 				}
-				else if ((_tokenSet_6.member(LA(1)))) {
+				else if ((_tokenSet_8.member(LA(1)))) {
 					matchNot('$');
 				}
 			else {
-				if ( _cnt44>=1 ) { break _loop44; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
+				if ( _cnt52>=1 ) { break _loop52; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
 			}
 			}
-			_cnt44++;
+			_cnt52++;
 		} while (true);
 		}
 		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
@@ -990,7 +1116,7 @@ tryAgain:
 		
 		match('{');
 		{
-		_loop60:
+		_loop70:
 		do {
 			switch ( LA(1)) {
 			case '{':
@@ -1004,11 +1130,11 @@ tryAgain:
 				break;
 			}
 			default:
-				if ((_tokenSet_7.member(LA(1)))) {
+				if ((_tokenSet_9.member(LA(1)))) {
 					matchNot('}');
 				}
 			else {
-				break _loop60;
+				break _loop70;
 			}
 			}
 		} while (true);
@@ -1031,16 +1157,16 @@ tryAgain:
 		{
 			match('"');
 			{
-			_loop47:
+			_loop55:
 			do {
 				if ((LA(1)=='\\')) {
 					mESC(false);
 				}
-				else if ((_tokenSet_8.member(LA(1)))) {
+				else if ((_tokenSet_10.member(LA(1)))) {
 					matchNot('"');
 				}
 				else {
-					break _loop47;
+					break _loop55;
 				}
 				
 			} while (true);
@@ -1085,10 +1211,10 @@ tryAgain:
 			
 			}
 			{
-			_loop52:
+			_loop60:
 			do {
 				// nongreedy exit test
-				if ((LA(1)=='>') && (LA(2)=='>') && ((LA(3) >= '\u0001' && LA(3) <= '\ufffe')) && (true) && (true) && (true) && (true)) break _loop52;
+				if ((LA(1)=='>') && (LA(2)=='>') && ((LA(3) >= '\u0001' && LA(3) <= '\ufffe')) && (true) && (true) && (true) && (true)) break _loop60;
 				if (((LA(1)=='\r') && (LA(2)=='\n') && ((LA(3) >= '\u0001' && LA(3) <= '\ufffe')) && ((LA(4) >= '\u0001' && LA(4) <= '\ufffe')) && ((LA(5) >= '\u0001' && LA(5) <= '\ufffe')) && (true) && (true))&&(LA(3)=='>'&&LA(4)=='>')) {
 					_saveIndex=text.length();
 					match('\r');
@@ -1129,7 +1255,7 @@ tryAgain:
 					matchNot(EOF_CHAR);
 				}
 				else {
-					break _loop52;
+					break _loop60;
 				}
 				
 			} while (true);
@@ -1156,8 +1282,8 @@ tryAgain:
 		
 		match('(');
 		{
-		int _cnt63=0;
-		_loop63:
+		int _cnt73=0;
+		_loop73:
 		do {
 			switch ( LA(1)) {
 			case '(':
@@ -1171,14 +1297,14 @@ tryAgain:
 				break;
 			}
 			default:
-				if ((_tokenSet_9.member(LA(1)))) {
+				if ((_tokenSet_11.member(LA(1)))) {
 					matchNot(')');
 				}
 			else {
-				if ( _cnt63>=1 ) { break _loop63; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
+				if ( _cnt73>=1 ) { break _loop73; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
 			}
 			}
-			_cnt63++;
+			_cnt73++;
 		} while (true);
 		}
 		match(')');
@@ -1189,6 +1315,43 @@ tryAgain:
 		_returnToken = _token;
 	}
 	
+	protected final void mHEX(boolean _createToken) throws RecognitionException, CharStreamException, TokenStreamException {
+		int _ttype; Token _token=null; int _begin=text.length();
+		_ttype = HEX;
+		int _saveIndex;
+		
+		switch ( LA(1)) {
+		case '0':  case '1':  case '2':  case '3':
+		case '4':  case '5':  case '6':  case '7':
+		case '8':  case '9':
+		{
+			matchRange('0','9');
+			break;
+		}
+		case 'A':  case 'B':  case 'C':  case 'D':
+		case 'E':  case 'F':
+		{
+			matchRange('A','F');
+			break;
+		}
+		case 'a':  case 'b':  case 'c':  case 'd':
+		case 'e':  case 'f':
+		{
+			matchRange('a','f');
+			break;
+		}
+		default:
+		{
+			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());
+		}
+		}
+		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
+			_token = makeToken(_ttype);
+			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
+		}
+		_returnToken = _token;
+	}
+	
 	
 	private static final long[] mk_tokenSet_0() {
 		long[] data = new long[2048];
@@ -1207,42 +1370,38 @@ tryAgain:
 	}
 	public static final BitSet _tokenSet_1 = new BitSet(mk_tokenSet_1());
 	private static final long[] mk_tokenSet_2() {
+		long[] data = new long[1025];
+		data[0]=4294967296L;
+		data[1]=14707067533131776L;
+		return data;
+	}
+	public static final BitSet _tokenSet_2 = new BitSet(mk_tokenSet_2());
+	private static final long[] mk_tokenSet_3() {
+		long[] data = new long[1025];
+		data[0]=287948969894477824L;
+		data[1]=541434314878L;
+		return data;
+	}
+	public static final BitSet _tokenSet_3 = new BitSet(mk_tokenSet_3());
+	private static final long[] mk_tokenSet_4() {
 		long[] data = new long[2048];
 		data[0]=-2199023255554L;
 		for (int i = 1; i<=1022; i++) { data[i]=-1L; }
 		data[1023]=9223372036854775807L;
 		return data;
 	}
-	public static final BitSet _tokenSet_2 = new BitSet(mk_tokenSet_2());
-	private static final long[] mk_tokenSet_3() {
+	public static final BitSet _tokenSet_4 = new BitSet(mk_tokenSet_4());
+	private static final long[] mk_tokenSet_5() {
 		long[] data = new long[2048];
 		data[0]=-1168231104514L;
 		for (int i = 1; i<=1022; i++) { data[i]=-1L; }
 		data[1023]=9223372036854775807L;
 		return data;
 	}
-	public static final BitSet _tokenSet_3 = new BitSet(mk_tokenSet_3());
-	private static final long[] mk_tokenSet_4() {
-		long[] data = new long[2048];
-		data[0]=-3298534892546L;
-		data[1]=-576460752571858945L;
-		for (int i = 2; i<=1022; i++) { data[i]=-1L; }
-		data[1023]=9223372036854775807L;
-		return data;
-	}
-	public static final BitSet _tokenSet_4 = new BitSet(mk_tokenSet_4());
-	private static final long[] mk_tokenSet_5() {
-		long[] data = new long[2048];
-		data[0]=-1152921521786716162L;
-		data[1]=-576460752303423489L;
-		for (int i = 2; i<=1022; i++) { data[i]=-1L; }
-		data[1023]=9223372036854775807L;
-		return data;
-	}
 	public static final BitSet _tokenSet_5 = new BitSet(mk_tokenSet_5());
 	private static final long[] mk_tokenSet_6() {
 		long[] data = new long[2048];
-		data[0]=-2305851874026202114L;
+		data[0]=-3298534892546L;
 		data[1]=-576460752571858945L;
 		for (int i = 2; i<=1022; i++) { data[i]=-1L; }
 		data[1023]=9223372036854775807L;
@@ -1251,8 +1410,8 @@ tryAgain:
 	public static final BitSet _tokenSet_6 = new BitSet(mk_tokenSet_6());
 	private static final long[] mk_tokenSet_7() {
 		long[] data = new long[2048];
-		data[0]=-2L;
-		data[1]=-2882303761785552897L;
+		data[0]=-1152921521786716162L;
+		data[1]=-576460752303423489L;
 		for (int i = 2; i<=1022; i++) { data[i]=-1L; }
 		data[1023]=9223372036854775807L;
 		return data;
@@ -1260,14 +1419,32 @@ tryAgain:
 	public static final BitSet _tokenSet_7 = new BitSet(mk_tokenSet_7());
 	private static final long[] mk_tokenSet_8() {
 		long[] data = new long[2048];
-		data[0]=-17179869186L;
-		data[1]=-268435457L;
+		data[0]=-2305851874026202114L;
+		data[1]=-576460752571858945L;
 		for (int i = 2; i<=1022; i++) { data[i]=-1L; }
 		data[1023]=9223372036854775807L;
 		return data;
 	}
 	public static final BitSet _tokenSet_8 = new BitSet(mk_tokenSet_8());
 	private static final long[] mk_tokenSet_9() {
+		long[] data = new long[2048];
+		data[0]=-2L;
+		data[1]=-2882303761785552897L;
+		for (int i = 2; i<=1022; i++) { data[i]=-1L; }
+		data[1023]=9223372036854775807L;
+		return data;
+	}
+	public static final BitSet _tokenSet_9 = new BitSet(mk_tokenSet_9());
+	private static final long[] mk_tokenSet_10() {
+		long[] data = new long[2048];
+		data[0]=-17179869186L;
+		data[1]=-268435457L;
+		for (int i = 2; i<=1022; i++) { data[i]=-1L; }
+		data[1023]=9223372036854775807L;
+		return data;
+	}
+	public static final BitSet _tokenSet_10 = new BitSet(mk_tokenSet_10());
+	private static final long[] mk_tokenSet_11() {
 		long[] data = new long[2048];
 		data[0]=-3298534883330L;
 		data[1]=-268435457L;
@@ -1275,6 +1452,6 @@ tryAgain:
 		data[1023]=9223372036854775807L;
 		return data;
 	}
-	public static final BitSet _tokenSet_9 = new BitSet(mk_tokenSet_9());
+	public static final BitSet _tokenSet_11 = new BitSet(mk_tokenSet_11());
 	
 	}
