@@ -1,4 +1,4 @@
-// $ANTLR 2.7.7 (20060906): "group.g" -> "GroupLexer.java"$
+// $ANTLR 2.7.7 (2006-01-29): "group.g" -> "GroupLexer.java"$
 
 /*
  [The "BSD licence"]
@@ -71,7 +71,7 @@ public GroupLexer(LexerSharedInputState state) {
 	caseSensitiveLiterals = true;
 	setCaseSensitive(true);
 	literals = new Hashtable();
-	literals.put(new ANTLRHashString("default", this), new Integer(20));
+	literals.put(new ANTLRHashString("default", this), new Integer(21));
 	literals.put(new ANTLRHashString("group", this), new Integer(4));
 	literals.put(new ANTLRHashString("implements", this), new Integer(7));
 }
@@ -92,13 +92,14 @@ tryAgain:
 				case 'M':  case 'N':  case 'O':  case 'P':
 				case 'Q':  case 'R':  case 'S':  case 'T':
 				case 'U':  case 'V':  case 'W':  case 'X':
-				case 'Y':  case 'Z':  case 'a':  case 'b':
-				case 'c':  case 'd':  case 'e':  case 'f':
-				case 'g':  case 'h':  case 'i':  case 'j':
-				case 'k':  case 'l':  case 'm':  case 'n':
-				case 'o':  case 'p':  case 'q':  case 'r':
-				case 's':  case 't':  case 'u':  case 'v':
-				case 'w':  case 'x':  case 'y':  case 'z':
+				case 'Y':  case 'Z':  case '_':  case 'a':
+				case 'b':  case 'c':  case 'd':  case 'e':
+				case 'f':  case 'g':  case 'h':  case 'i':
+				case 'j':  case 'k':  case 'l':  case 'm':
+				case 'n':  case 'o':  case 'p':  case 'q':
+				case 'r':  case 's':  case 't':  case 'u':
+				case 'v':  case 'w':  case 'x':  case 'y':
+				case 'z':
 				{
 					mID(true);
 					theRetToken=_returnToken;
@@ -225,7 +226,6 @@ tryAgain:
 				}
 				if ( _returnToken==null ) continue tryAgain; // found SKIP token
 				_ttype = _returnToken.getType();
-				_ttype = testLiteralsTable(_ttype);
 				_returnToken.setType(_ttype);
 				return _returnToken;
 			}
@@ -273,6 +273,11 @@ tryAgain:
 			matchRange('A','Z');
 			break;
 		}
+		case '_':
+		{
+			match('_');
+			break;
+		}
 		default:
 		{
 			throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());
@@ -280,7 +285,7 @@ tryAgain:
 		}
 		}
 		{
-		_loop27:
+		_loop29:
 		do {
 			switch ( LA(1)) {
 			case 'a':  case 'b':  case 'c':  case 'd':
@@ -324,11 +329,12 @@ tryAgain:
 			}
 			default:
 			{
-				break _loop27;
+				break _loop29;
 			}
 			}
 		} while (true);
 		}
+		_ttype = testLiteralsTable(_ttype);
 		if ( _createToken && _token==null && _ttype!=Token.SKIP ) {
 			_token = makeToken(_ttype);
 			_token.setText(new String(text.getBuffer(), _begin, text.length()-_begin));
@@ -345,7 +351,7 @@ tryAgain:
 		match('"');
 		text.setLength(_saveIndex);
 		{
-		_loop30:
+		_loop32:
 		do {
 			if ((LA(1)=='\\') && (LA(2)=='"')) {
 				_saveIndex=text.length();
@@ -361,7 +367,7 @@ tryAgain:
 				matchNot('"');
 			}
 			else {
-				break _loop30;
+				break _loop32;
 			}
 			
 		} while (true);
@@ -418,10 +424,10 @@ tryAgain:
 		
 		}
 		{
-		_loop36:
+		_loop38:
 		do {
 			// nongreedy exit test
-			if ((LA(1)=='>') && (LA(2)=='>')) break _loop36;
+			if ((LA(1)=='>') && (LA(2)=='>')) break _loop38;
 			if (((LA(1)=='\r') && (LA(2)=='\n'))&&(LA(3)=='>'&&LA(4)=='>')) {
 				_saveIndex=text.length();
 				match('\r');
@@ -468,7 +474,7 @@ tryAgain:
 				matchNot(EOF_CHAR);
 			}
 			else {
-				break _loop36;
+				break _loop38;
 			}
 			
 		} while (true);
@@ -496,10 +502,10 @@ tryAgain:
 		match('{');
 		text.setLength(_saveIndex);
 		{
-		_loop40:
+		_loop42:
 		do {
 			// nongreedy exit test
-			if ((LA(1)=='}') && (true)) break _loop40;
+			if ((LA(1)=='}') && (true)) break _loop42;
 			if ((LA(1)=='\n'||LA(1)=='\r') && ((LA(2) >= '\u0000' && LA(2) <= '\ufffe'))) {
 				{
 				switch ( LA(1)) {
@@ -531,7 +537,7 @@ tryAgain:
 				matchNot(EOF_CHAR);
 			}
 			else {
-				break _loop40;
+				break _loop42;
 			}
 			
 		} while (true);
@@ -735,7 +741,7 @@ tryAgain:
 		
 		match("//");
 		{
-		_loop58:
+		_loop60:
 		do {
 			if ((_tokenSet_2.member(LA(1)))) {
 				{
@@ -743,7 +749,7 @@ tryAgain:
 				}
 			}
 			else {
-				break _loop58;
+				break _loop60;
 			}
 			
 		} while (true);
@@ -788,10 +794,10 @@ tryAgain:
 		
 		match("/*");
 		{
-		_loop64:
+		_loop66:
 		do {
 			// nongreedy exit test
-			if ((LA(1)=='*') && (LA(2)=='/')) break _loop64;
+			if ((LA(1)=='*') && (LA(2)=='/')) break _loop66;
 			if ((LA(1)=='\n'||LA(1)=='\r') && ((LA(2) >= '\u0000' && LA(2) <= '\ufffe'))) {
 				{
 				switch ( LA(1)) {
@@ -817,7 +823,7 @@ tryAgain:
 				matchNot(EOF_CHAR);
 			}
 			else {
-				break _loop64;
+				break _loop66;
 			}
 			
 		} while (true);
@@ -837,8 +843,8 @@ tryAgain:
 		int _saveIndex;
 		
 		{
-		int _cnt68=0;
-		_loop68:
+		int _cnt70=0;
+		_loop70:
 		do {
 			switch ( LA(1)) {
 			case ' ':
@@ -881,10 +887,10 @@ tryAgain:
 			}
 			default:
 			{
-				if ( _cnt68>=1 ) { break _loop68; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
+				if ( _cnt70>=1 ) { break _loop70; } else {throw new NoViableAltForCharException((char)LA(1), getFilename(), getLine(), getColumn());}
 			}
 			}
-			_cnt68++;
+			_cnt70++;
 		} while (true);
 		}
 		_ttype = Token.SKIP;
